#[non_exhaustive]pub enum CompositeKeyParseError {
MissingSeparator {
separator: char,
},
InvalidFirst(KeyParseError),
InvalidSecond(KeyParseError),
}Expand description
Error type for composite key parsing failures.
Returned by CompositeKey::from_str when the input
string cannot be parsed as a valid CompositeKey.
Variants
MissingSeparator— the separator character was not found.InvalidFirst— the first component failed validation.InvalidSecond— the second component failed validation.
Examples
use domain_key::{CompositeKey, CompositeKeyParseError};
use domain_key::{Domain, KeyDomain};
#[derive(Debug)]
struct UserDomain;
impl Domain for UserDomain { const DOMAIN_NAME: &'static str = "user"; }
impl KeyDomain for UserDomain {}
#[derive(Debug)]
struct PostDomain;
impl Domain for PostDomain { const DOMAIN_NAME: &'static str = "post"; }
impl KeyDomain for PostDomain {}
let err = "no-separator-here"
.parse::<CompositeKey<UserDomain, PostDomain>>()
.unwrap_err();
assert!(matches!(err, CompositeKeyParseError::MissingSeparator { separator: ':' }));Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MissingSeparator
The separator character was not found in the input string.
InvalidFirst(KeyParseError)
The first component of the composite key failed to parse.
InvalidSecond(KeyParseError)
The second component of the composite key failed to parse.