pub fn format_debug_error(error: &KeyParseError) -> StringExpand description
Format an error for logging or debugging
This function provides a detailed representation suitable for logs, including error codes and categories.
pub fn format_debug_error(error: &KeyParseError) -> StringFormat an error for logging or debugging
This function provides a detailed representation suitable for logs, including error codes and categories.