pub fn format_user_error(error: &KeyParseError) -> StringExpand description
Format an error for display to end users
This function provides a user-friendly representation of validation errors, including suggestions for how to fix them.
pub fn format_user_error(error: &KeyParseError) -> StringFormat an error for display to end users
This function provides a user-friendly representation of validation errors, including suggestions for how to fix them.