#[non_exhaustive]pub enum ErrorCategory {
Length,
Character,
Structure,
Domain,
Custom,
}Expand description
Error category for classification of validation errors
These categories allow applications to handle broad types of validation errors uniformly, regardless of the specific error details.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Length
Length-related errors (empty, too long)
Character
Character-related errors (invalid characters)
Structure
Structure-related errors (invalid format, consecutive special chars)
Domain
Domain-specific validation errors
Custom
Custom validation errors
Implementations
Sourceimpl ErrorCategory
impl ErrorCategory