#[non_exhaustive]pub enum IdParseError {
Zero,
InvalidNumber(ParseIntError),
}Expand description
Error type for numeric ID parsing failures
This error is returned when a string cannot be parsed as a valid Id<D>.
Examples
use domain_key::IdParseError;
let result = "not_a_number".parse::<u64>();
assert!(result.is_err());Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Zero
The value is zero, which is not a valid identifier
InvalidNumber(ParseIntError)
The string could not be parsed as a valid non-zero u64 number
Implementations
Sourceimpl IdParseError
impl IdParseError
Sourcepub fn user_message(&self) -> &'static str
pub fn user_message(&self) -> &'static str
Returns a user-friendly error message suitable for display.